/* Copyright (C) 2010-2023 Frankfurt Institute for Advanced Studies, Goethe-Universitaet Frankfurt, Frankfurt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Ivan Kisel,  Sergey Gorbunov, Maksym Zyzak, Igor Kulakov [committer], Sergei Zharko */

/// \file   CaTrack.h
/// \brief  header file for the ca::Track class
/// \since  02.06.2022
/// \author S.Zharko <s.zharko@gsi.de>

#pragma once  // include this header only once per compilation unit

#include <boost/serialization/access.hpp>

#include "CaConstants.h"
#include "CaSimd.h"
#include "CaTrackParam.h"

namespace cbm::algo::ca
{
  /// \class cbm::algo::ca::Track
  /// \brief Class representing an output track in the CA tracking algorithm
  ///
  /// Track parameters vector: {x, y, tx, ty, q/p, z, t, vi}
  /// Covariation matrix: C[20] (C55) corresponds to the time variance
  ///
  class Track {
  public:
    friend class boost::serialization::access;

    Track() = default;

    template<class Archive>
    void serialize(Archive& ar, const unsigned int /*version*/)
    {
      ar& fNofHits;
      ar& fParFirst;
      ar& fParLast;
      ar& fParPV;
    }

  public:
    int fNofHits {constants::Undef<int>};  ///< Number of hits in track

    TrackParamS fParFirst;  ///< Track parameters on the first station
    TrackParamS fParLast;   ///< Track parameters on the last station
    TrackParamS fParPV;     ///< Track parameters in the primary vertex
  };

}  // namespace cbm::algo::ca
