/* Copyright (C) 2023 Facility for Antiproton and Ion Research in Europe, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Dominik Smith [committer], Felix Weiglhofer */
#include "CalibratorChain.h"

#include "config/Yaml.h"

using namespace cbm::algo;
using namespace cbm::algo::tof;

void CalibratorChain::Init()
{
  auto setup             = config::ReadFromFile<CalibrateSetup>(Opts().ParamsDir() / "TofCalibratePar.yaml");
  fCalibrate             = std::make_unique<Calibrate>();
  fCalibrate->fTofConfig = setup;
}

CalibratorChain::ReturnType CalibratorChain::Run(gsl::span<CbmTofDigi> digis)
{
  auto ret = (*fCalibrate)(digis);

  auto nUnknownRPC = std::get<1>(ret).fDigiCalibUnknownRPC;
  if (nUnknownRPC > 0) L_(error) << "TOF Digis with unknown RPCs: " << nUnknownRPC;
  return ret;
}
