/* Copyright (C) 2022 Facility for Antiproton and Ion Research in Europe, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Dominik Smith [committer], Pierre-Alain Loizeau */

/*
   This algo was based on CbmTofEventClusterizer
*/

#ifndef CLUSTERIZERTOF_H
#define CLUSTERIZERTOF_H

// TOF Classes and includes
class CbmTofDigi;

#include "ClusterizerPars.h"
#include "Hit.h"

// C++ Classes and includes
#include <memory>
#include <vector>

#include <cmath>

namespace cbm::algo::tof
{
  class Clusterizer {
  public:
    typedef std::vector<Hit> resultType;
    typedef std::vector<std::pair<CbmTofDigi*, int32_t>> inputType;

    /**
       ** @brief Constructor.
       **/
    Clusterizer() {};

    /**
       ** @brief Destructor.
       **/
    ~Clusterizer() {};

    /**
       ** @brief Build clusters out of ToF Digis and store the resulting info in a TofHit.
       **/
    resultType operator()(const inputType& digisIn);

    /** @brief Set the parameter container
     ** @param params Vectorer to parameter container
     **/
    void SetParams(std::unique_ptr<ClusterizerRpcPar> params) { fParams = *(std::move(params)); }

  private:
    ClusterizerRpcPar fParams = {};  ///< Parameter container

    std::vector<inputType> chanSortDigis(const inputType& digisIn);

    resultType buildClusters(std::vector<inputType>& input);

    bool AddNextChan(std::vector<inputType>& input, int32_t iLastChan, Hit& cluster, std::vector<Hit>& clustersOut,
                     std::vector<inputType::iterator>* lastChanPos = nullptr);
  };

}  // namespace cbm::algo::tof

#endif  // CLUSTERIZERTOF_H
